Name:    dosbox-staging
Version: 0.78.1
Release: 2%{?dist}
Summary: DOS/x86 emulator focusing on ease of use
URL:     https://dosbox-staging.github.io/

# Bundled dependencies bring their licenses with them.
# Breakdown is given here, actual License tag is simplified
# according to Fedora effective licensing rules.
#
# src/libs/decoders/std.h is another bundled dependency,
# but apparently not used.
# It is removed in %%prep to be sure.
#
# Main license:      GPLv2+
# archive:           Unlicense
# dr_libs:           Unlicense or MIT-0
# enet:              MIT
# gulrak-filesystem: MIT
# src/libs/gui_tk:   GPLv3+
# libsidplayfp:      GPLv2+
# src/lib/loguru:    Public Domain
# src/lib/ppscale:   Fair
# src/lib/nuked:     LGPLv2+
# stb_vorbis:        MIT or Unlicense
# src/libs/whereami: MIT or WTFPL
# xxhash:            BSD
License: GPLv3+

Source0: https://github.com/dosbox-staging/dosbox-staging/archive/v%{version}/%{name}-%{version}.tar.gz

# This package is a drop-in replacement for dosbox
Provides:  dosbox = %{version}-%{release}
Obsoletes: dosbox < 0.74.4

BuildRequires: alsa-lib-devel
BuildRequires: desktop-file-utils
BuildRequires: fluidsynth-devel >= 2.0
BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: git
BuildRequires: gmock-devel
BuildRequires: gtest-devel
BuildRequires: libappstream-glib
BuildRequires: libatomic
BuildRequires: libpng-devel
BuildRequires: libslirp-devel
BuildRequires: make
BuildRequires: meson
BuildRequires: mt32emu-devel
BuildRequires: opusfile-devel
BuildRequires: SDL2-devel >= 2.0.5
BuildRequires: SDL2_net-devel

Requires: hicolor-icon-theme
Requires: fluid-soundfont-gm

# src/lib/enet
# Based on fork github.com/lsalzman/enet
Provides: bundled(enet)
# src/lib/ghc
Provides: bundled(gulrak-filesystem)
# src/lib/gui_tk
# Not in Fedora, upstream seems to have disappeared completely
Provides: bundled(gui_tk)
# src/lib/loguru
# Not in Fedora, upstream https://github.com/emilk/loguru
Provides: bundled(loguru)
# src/lib/nuked
# Not in Fedora, upstream https://github.com/nukeykt/Nuked-OPL3
Provides: bundled(nuked-opl3)
# src/lib/residfp
# Not the whole library, just the residfp part
Provides: bundled(libsidplayfp)
# src/lib/whereami
# Not in Fedora, upstream https://github.com/gpakosz/whereami
Provides: bundled(gpakosz-whereami)
# src/lib/decoders/archive.h
# Not in Fedora, upstream github.com/voidah/archive
Provides: bundled(archive)
# src/lib/decoders/dr_{flac,mp3,wav}.h
Provides: bundled(dr_libs)
# src/lib/decoders/stb_vorbis.h
Provides: bundled(stb_vorbis)
# src/lib/decoders/xxhash.h
Provides: bundled(xxhash)


%description
DOSBox Staging is full x86 CPU emulator (independent of host architecture),
capable of running DOS programs that require real or protected mode.

It features built-in DOS-like shell terminal, emulation of several PC variants
(IBM PC, IBM PCjr, Tandy 1000), CPUs (286, 386, 486, Pentium I), graphic
chipsets (Hercules, CGA, EGA, VGA, SVGA), audio solutions (Sound Blaster,
Gravis UltraSound, Disney Sound Source, Tandy Sound System), CD Digital Audio
emulation (also with audio encoded as FLAC, Opus, OGG/Vorbis, MP3 or WAV),
joystick emulation (supports modern game controllers), serial port emulation,
IPX over UDP, GLSL shaders, and more.

DOSBox Staging is highly configurable, well-optimized and fast enough to run
any old DOS game using modern hardware.


%prep
%autosetup -p1
# Remove unused file
rm src/libs/decoders/stb.h


%build
%meson
%meson_build


%install
%meson_install
# Install bash completion files
mkdir -p  %{buildroot}%{_datadir}/bash-completion/completions
cp contrib/linux/bash-completion/dosbox %{buildroot}%{_datadir}/bash-completion/completions


%check
%meson_test
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.xml


%files
%license COPYING
%doc AUTHORS README THANKS
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/applications/*
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/dosbox
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/*/apps/dosbox-staging.*
%{_metainfodir}/*


%changelog
* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.78.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Jan 08 2022 Otto Urpelainen <oturpe@iki.fi> - 0.78.1-1
- Update to 0.78.1

* Mon Jan 03 2022 Otto Urpelainen <oturpe@iki.fi> - 0.78.0-3
- Patch crash when calling EXIT in fullscreen mode
- Add virtual provides for bundled dependencies
- Update license to comply with bundled dependencies' licenses

* Sun Jan 02 2022 Otto Urpelainen <oturpe@iki.fi> - 0.78.0-2
- Fix build on 32 bit arches

* Sat Jan 01 2022 Otto Urpelainen <oturpe@iki.fi> - 0.78.0-1
- Update to 0.78.0
- Add translations
- Add bash completion

* Mon Sep 20 2021 Otto Urpelainen <oturpe@iki.fi> - 0.77.1-1
- Update to 0.77.1
- Resolves rhbz#2001461

* Fri Jul 23 2021 Otto Urpelainen <oturpe@iki.fi> - 0.77.0-4
- Use system mt32emu instead of bundling it

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.77.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sun Jul 04 2021 Patryk Obara (pbo) <dreamer.tan@gmail.com>
- 0.77.0-2
- Indicate bundled mt32emu library via "Provides" tag
- Raise minimum SDL version to 2.0.5

* Sat Jul 03 2021 Patryk Obara (pbo) <dreamer.tan@gmail.com>
- 0.77.0-1
- Update to 0.77.0
- Replace Autotools with Meson

* Mon Jun 21 2021 Gwyn Ciesla <gwync@protonmail.com> - 0.76.0-3
- Fluidsynth rebuild.

* Tue Jan 26 2021 Patryk Obara (pbo) <dreamer.tan@gmail.com>
- 0.76.0-2
- Tighten dependencies checks

* Mon Jan 25 2021 Patryk Obara (pbo) <dreamer.tan@gmail.com>
- 0.76.0-1
- Update to 0.76.0
- Add fluidsynth-devel build dependency (new feature)
- Add fluid-soundfont-gm runtime dependency (default soundfont)

* Tue Oct 27 2020 Patryk Obara (pbo) <dreamer.tan@gmail.com>
- 0.75.2-1
- Update to 0.75.2

* Thu Oct 01 2020 Patryk Obara (pbo) <dreamer.tan@gmail.com>
- 0.75.1-1
- Initial release.
